torchcurves
===========

.. automodule:: torchcurves
.. automodule:: torchcurves.modules


.. contents:: torchcurves
    :depth: 2
    :local:
    :backlinks: top


.. currentmodule:: torchcurves

Layers
------

.. autosummary::
   :toctree: generated
   :nosignatures:
   :template: classtemplate.rst

   BSplineEmbeddings
   BSplineCurve
   LegendreCurve
   Sum
